==> types_boto3_cloudwatch-1.35.74-py3-none-any.whl: types_boto3_cloudwatch/paginator.py <==
"""
Type annotations for cloudwatch service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_cloudwatch.client import CloudWatchClient
    from types_boto3_cloudwatch.paginator import (
        DescribeAlarmHistoryPaginator,
        DescribeAlarmsPaginator,
        DescribeAnomalyDetectorsPaginator,
        GetMetricDataPaginator,
        ListDashboardsPaginator,
        ListMetricsPaginator,
    )

    session = Session()
    client: CloudWatchClient = session.client("cloudwatch")

    describe_alarm_history_paginator: DescribeAlarmHistoryPaginator = client.get_paginator("describe_alarm_history")
    describe_alarms_paginator: DescribeAlarmsPaginator = client.get_paginator("describe_alarms")
    describe_anomaly_detectors_paginator: DescribeAnomalyDetectorsPaginator = client.get_paginator("describe_anomaly_detectors")
    get_metric_data_paginator: GetMetricDataPaginator = client.get_paginator("get_metric_data")
    list_dashboards_paginator: ListDashboardsPaginator = client.get_paginator("list_dashboards")
    list_metrics_paginator: ListMetricsPaginator = client.get_paginator("list_metrics")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    DescribeAlarmHistoryInputDescribeAlarmHistoryPaginateTypeDef,
    DescribeAlarmHistoryOutputTypeDef,
    DescribeAlarmsInputDescribeAlarmsPaginateTypeDef,
    DescribeAlarmsOutputTypeDef,
    DescribeAnomalyDetectorsInputDescribeAnomalyDetectorsPaginateTypeDef,
    DescribeAnomalyDetectorsOutputTypeDef,
    GetMetricDataInputGetMetricDataPaginateTypeDef,
    GetMetricDataOutputTypeDef,
    ListDashboardsInputListDashboardsPaginateTypeDef,
    ListDashboardsOutputTypeDef,
    ListMetricsInputListMetricsPaginateTypeDef,
    ListMetricsOutputTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "DescribeAlarmHistoryPaginator",
    "DescribeAlarmsPaginator",
    "DescribeAnomalyDetectorsPaginator",
    "GetMetricDataPaginator",
    "ListDashboardsPaginator",
    "ListMetricsPaginator",
)


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class DescribeAlarmHistoryPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/paginator/DescribeAlarmHistory.html#CloudWatch.Paginator.DescribeAlarmHistory)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/paginators/#describealarmhistorypaginator)
    """

    def paginate(
        self, **kwargs: Unpack[DescribeAlarmHistoryInputDescribeAlarmHistoryPaginateTypeDef]
    ) -> _PageIterator[DescribeAlarmHistoryOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/paginator/DescribeAlarmHistory.html#CloudWatch.Paginator.DescribeAlarmHistory.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/paginators/#describealarmhistorypaginator)
        """


class DescribeAlarmsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/paginator/DescribeAlarms.html#CloudWatch.Paginator.DescribeAlarms)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/paginators/#describealarmspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[DescribeAlarmsInputDescribeAlarmsPaginateTypeDef]
    ) -> _PageIterator[DescribeAlarmsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/paginator/DescribeAlarms.html#CloudWatch.Paginator.DescribeAlarms.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/paginators/#describealarmspaginator)
        """


class DescribeAnomalyDetectorsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/paginator/DescribeAnomalyDetectors.html#CloudWatch.Paginator.DescribeAnomalyDetectors)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/paginators/#describeanomalydetectorspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[DescribeAnomalyDetectorsInputDescribeAnomalyDetectorsPaginateTypeDef]
    ) -> _PageIterator[DescribeAnomalyDetectorsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/paginator/DescribeAnomalyDetectors.html#CloudWatch.Paginator.DescribeAnomalyDetectors.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/paginators/#describeanomalydetectorspaginator)
        """


class GetMetricDataPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/paginator/GetMetricData.html#CloudWatch.Paginator.GetMetricData)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/paginators/#getmetricdatapaginator)
    """

    def paginate(
        self, **kwargs: Unpack[GetMetricDataInputGetMetricDataPaginateTypeDef]
    ) -> _PageIterator[GetMetricDataOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/paginator/GetMetricData.html#CloudWatch.Paginator.GetMetricData.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/paginators/#getmetricdatapaginator)
        """


class ListDashboardsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/paginator/ListDashboards.html#CloudWatch.Paginator.ListDashboards)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/paginators/#listdashboardspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListDashboardsInputListDashboardsPaginateTypeDef]
    ) -> _PageIterator[ListDashboardsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/paginator/ListDashboards.html#CloudWatch.Paginator.ListDashboards.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/paginators/#listdashboardspaginator)
        """


class ListMetricsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/paginator/ListMetrics.html#CloudWatch.Paginator.ListMetrics)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/paginators/#listmetricspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListMetricsInputListMetricsPaginateTypeDef]
    ) -> _PageIterator[ListMetricsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/paginator/ListMetrics.html#CloudWatch.Paginator.ListMetrics.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/paginators/#listmetricspaginator)
        """

==> types_boto3_cloudwatch-1.35.93-py3-none-any.whl: types_boto3_cloudwatch/paginator.py <==
"""
Type annotations for cloudwatch service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_cloudwatch.client import CloudWatchClient
    from types_boto3_cloudwatch.paginator import (
        DescribeAlarmHistoryPaginator,
        DescribeAlarmsPaginator,
        DescribeAnomalyDetectorsPaginator,
        GetMetricDataPaginator,
        ListDashboardsPaginator,
        ListMetricsPaginator,
    )

    session = Session()
    client: CloudWatchClient = session.client("cloudwatch")

    describe_alarm_history_paginator: DescribeAlarmHistoryPaginator = client.get_paginator("describe_alarm_history")
    describe_alarms_paginator: DescribeAlarmsPaginator = client.get_paginator("describe_alarms")
    describe_anomaly_detectors_paginator: DescribeAnomalyDetectorsPaginator = client.get_paginator("describe_anomaly_detectors")
    get_metric_data_paginator: GetMetricDataPaginator = client.get_paginator("get_metric_data")
    list_dashboards_paginator: ListDashboardsPaginator = client.get_paginator("list_dashboards")
    list_metrics_paginator: ListMetricsPaginator = client.get_paginator("list_metrics")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    DescribeAlarmHistoryInputPaginateTypeDef,
    DescribeAlarmHistoryOutputTypeDef,
    DescribeAlarmsInputPaginateTypeDef,
    DescribeAlarmsOutputTypeDef,
    DescribeAnomalyDetectorsInputPaginateTypeDef,
    DescribeAnomalyDetectorsOutputTypeDef,
    GetMetricDataInputPaginateTypeDef,
    GetMetricDataOutputTypeDef,
    ListDashboardsInputPaginateTypeDef,
    ListDashboardsOutputTypeDef,
    ListMetricsInputPaginateTypeDef,
    ListMetricsOutputTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "DescribeAlarmHistoryPaginator",
    "DescribeAlarmsPaginator",
    "DescribeAnomalyDetectorsPaginator",
    "GetMetricDataPaginator",
    "ListDashboardsPaginator",
    "ListMetricsPaginator",
)


if TYPE_CHECKING:
    _DescribeAlarmHistoryPaginatorBase = Paginator[DescribeAlarmHistoryOutputTypeDef]
else:
    _DescribeAlarmHistoryPaginatorBase = Paginator  # type: ignore[assignment]


class DescribeAlarmHistoryPaginator(_DescribeAlarmHistoryPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/paginator/DescribeAlarmHistory.html#CloudWatch.Paginator.DescribeAlarmHistory)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/paginators/#describealarmhistorypaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeAlarmHistoryInputPaginateTypeDef]
    ) -> PageIterator[DescribeAlarmHistoryOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/paginator/DescribeAlarmHistory.html#CloudWatch.Paginator.DescribeAlarmHistory.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/paginators/#describealarmhistorypaginator)
        """


if TYPE_CHECKING:
    _DescribeAlarmsPaginatorBase = Paginator[DescribeAlarmsOutputTypeDef]
else:
    _DescribeAlarmsPaginatorBase = Paginator  # type: ignore[assignment]


class DescribeAlarmsPaginator(_DescribeAlarmsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/paginator/DescribeAlarms.html#CloudWatch.Paginator.DescribeAlarms)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/paginators/#describealarmspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeAlarmsInputPaginateTypeDef]
    ) -> PageIterator[DescribeAlarmsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/paginator/DescribeAlarms.html#CloudWatch.Paginator.DescribeAlarms.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/paginators/#describealarmspaginator)
        """


if TYPE_CHECKING:
    _DescribeAnomalyDetectorsPaginatorBase = Paginator[DescribeAnomalyDetectorsOutputTypeDef]
else:
    _DescribeAnomalyDetectorsPaginatorBase = Paginator  # type: ignore[assignment]


class DescribeAnomalyDetectorsPaginator(_DescribeAnomalyDetectorsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/paginator/DescribeAnomalyDetectors.html#CloudWatch.Paginator.DescribeAnomalyDetectors)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/paginators/#describeanomalydetectorspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeAnomalyDetectorsInputPaginateTypeDef]
    ) -> PageIterator[DescribeAnomalyDetectorsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/paginator/DescribeAnomalyDetectors.html#CloudWatch.Paginator.DescribeAnomalyDetectors.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/paginators/#describeanomalydetectorspaginator)
        """


if TYPE_CHECKING:
    _GetMetricDataPaginatorBase = Paginator[GetMetricDataOutputTypeDef]
else:
    _GetMetricDataPaginatorBase = Paginator  # type: ignore[assignment]


class GetMetricDataPaginator(_GetMetricDataPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/paginator/GetMetricData.html#CloudWatch.Paginator.GetMetricData)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/paginators/#getmetricdatapaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[GetMetricDataInputPaginateTypeDef]
    ) -> PageIterator[GetMetricDataOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/paginator/GetMetricData.html#CloudWatch.Paginator.GetMetricData.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/paginators/#getmetricdatapaginator)
        """


if TYPE_CHECKING:
    _ListDashboardsPaginatorBase = Paginator[ListDashboardsOutputTypeDef]
else:
    _ListDashboardsPaginatorBase = Paginator  # type: ignore[assignment]


class ListDashboardsPaginator(_ListDashboardsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/paginator/ListDashboards.html#CloudWatch.Paginator.ListDashboards)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/paginators/#listdashboardspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListDashboardsInputPaginateTypeDef]
    ) -> PageIterator[ListDashboardsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/paginator/ListDashboards.html#CloudWatch.Paginator.ListDashboards.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/paginators/#listdashboardspaginator)
        """


if TYPE_CHECKING:
    _ListMetricsPaginatorBase = Paginator[ListMetricsOutputTypeDef]
else:
    _ListMetricsPaginatorBase = Paginator  # type: ignore[assignment]


class ListMetricsPaginator(_ListMetricsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/paginator/ListMetrics.html#CloudWatch.Paginator.ListMetrics)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/paginators/#listmetricspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListMetricsInputPaginateTypeDef]
    ) -> PageIterator[ListMetricsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch/paginator/ListMetrics.html#CloudWatch.Paginator.ListMetrics.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudwatch/paginators/#listmetricspaginator)
        """
